@@ -13,7 +13,7 @@ use Time::Piece ();
 
 has 'mysql';
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 sub dequeue {
   my ($self, $worker_id, $wait, $options) = @_;
@@ -1085,7 +1085,7 @@ Minion::Backend::mysql
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
@@ -1507,7 +1507,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alexander Nalobin Dmitry Krylov Jason A. Crome Larry Leszczynski Olaf Alders Paul Cochrane Zoffix Znet
+=for stopwords Alexander Nalobin Dmitry Krylov Hu Yin Jason A. Crome Larry Leszczynski Olaf Alders Paul Cochrane Zoffix Znet
 
 =over 4
 
@@ -1521,6 +1521,10 @@ Dmitry Krylov <pentabion@gmail.com>
 
 =item *
 
+Hu Yin <huyin8@gmail.com>
+
+=item *
+
 Jason A. Crome <jcrome@empoweredbenefits.com>
 
 =item *
@@ -1695,3 +1699,10 @@ DROP INDEX minion_jobs_expires ON minion_jobs;
 ALTER TABLE minion_jobs DROP COLUMN expires;
 ALTER TABLE minion_jobs DROP COLUMN lax;
 
+-- 8 up
+ALTER TABLE minion_jobs_depends
+    ADD PRIMARY KEY (parent_id, child_id);
+
+-- 8 down
+ALTER TABLE minion_jobs_depends
+    DROP PRIMARY KEY;
